use super::{NPCSayInfo, NPCSayType, NPCSpawnPossession, NPC};
use crate::{
    models::{
        consent::ConsentType,
        item::{LocationActionType, Pronouns, SkillType},
    },
    static_content::{npc::KillBonus, possession_type::PossessionType, species::SpeciesType},
};

pub fn npc_list() -> Vec<NPC> {
    use NPCSayType::FromFixedList;
    let geek_stdsay = NPCSayInfo {
        say_code: "babble",
        frequency_secs: 120,
        talk_type: FromFixedList(vec!(
            (false, "I wish I could get into the secret hackers club - I heard they have a machine that hacks your wristpad to make you a super smart dork."),
            (false, "The basement here is pretty dangerous with all those robots."),
            (false, "I overhead a real dork bragging about how he managed to get all four rings onto the rightmost virtual peg. No idea what that was about!"),
            (false, "Why is it that all the dorks around here keep whispering stuff to each other about Towers of Hanoi?"),
        ))
    };

    let killbot_stdsay = NPCSayInfo {
        say_code: "babble",
        frequency_secs: 20,
        talk_type: FromFixedList(vec!(
            (false, "My mission is to EXTERMINATE"),
            (false, "Intruder kill mode active"),
            (false, "Recoverable Error: Preset Kill Limit not set. Treating as unlimited"),
            (false, "404 action module STUN not found. Falling back to action KILL underscore WITH underscore EXTREME underscore PREJUDICE"),
        ))
    };

    macro_rules! geek_gender_word {
        (default_male) => {
            "guy"
        };
        (default_female) => {
            "gal"
        };
    }

    macro_rules! geek {
        ($code: expr, $adj: expr, $spawn: expr, $pronouns: ident) => {
            NPC {
                code: concat!("computer_museum_geek_", $code),
                name: concat!($adj, " geek"),
                pronouns: Pronouns { is_proper: false, ..Pronouns::$pronouns() },
                description: concat!("A geeky looking ", geek_gender_word!($pronouns), " with horn-rimmed glasses, and a button-down shirt. In the pocket is a pocket protector"),
                spawn_location: concat!("room/computer_museum_", $spawn),
                spawn_possessions: vec![
                    NPCSpawnPossession {
                        what: PossessionType::Shirt,
                        action_type: LocationActionType::Worn,
                        wear_layer: 0,
                    },
                    NPCSpawnPossession {
                        what: PossessionType::Jeans,
                        action_type: LocationActionType::Worn,
                        wear_layer: 0,
                    },
                ],
                message_handler: None,
                wander_zones: vec!("computer_museum"),
                says: vec!(geek_stdsay.clone()),
                player_consents: vec!(ConsentType::Medicine),
                ..Default::default()
            }
        }
    }

    macro_rules! killbot {
        ($code: expr, $adj: expr, $spawn: expr) => {
            NPC {
                code: concat!("computer_museum_killbot_", $code),
                name: concat!($adj, " Killbot"),
                species: SpeciesType::Robot,
                pronouns: Pronouns {
                    is_proper: false,
                    ..Pronouns::default_inanimate()
                },
                description: concat!("A mean looking robot, complete with a vicious spiked mace and powerful solonoids for smashing it hard into whatever unfortunate victim this bot targets"),
                spawn_location: concat!("room/computer_museum_", $spawn),
                spawn_possessions: vec![],
                aggression: 21,
                aggro_pc_only: true,
                total_xp: 3000,
                total_skills: SkillType::values()
                    .into_iter()
                    .map(|sk| {
                        (
                            sk.clone(),
                            if &sk == &SkillType::Clubs { 12.0 } else { 10.0 },
                        )
                    })
                    .collect(),
                intrinsic_weapon: Some(PossessionType::SpikedMace),
                message_handler: None,
                wander_zones: vec!["computer_museum"],
                kill_bonus: Some(KillBonus {
                    msg: "On your wristpad: Those robots have been the bane of our existence at the museum. Thanks for taking one out! Here's a small token of our gratitude.",
                    payment: 120,
                }),
                says: vec![killbot_stdsay.clone()],
                player_consents: vec![ConsentType::Fight],
                ..Default::default()
            }
        };
    }

    vec![
        geek!("1", "excited", "lobby", default_male),
        geek!("2", "mesmerised", "lobby", default_female),
        killbot!("3", "abhorrent", "hw_1"),
        killbot!("4", "berserk", "hw_2"),
        killbot!("5", "vicious", "hw_3"),
        killbot!("6", "murderous", "club_door"),
    ]
}
