use super::{Direction, Exit, ExitTarget, GridCoords, Room, SecondaryZoneRecord};
use ansi::ansi;
pub fn room_list() -> Vec<Room> {
    vec!(
        Room {
            zone: "computer_museum",
            secondary_zones: vec!(
                SecondaryZoneRecord {
                    zone: "melbs",
                    short: ansi!("<bgyellow><blue>CM<reset>"),
                    grid_coords: GridCoords { x: 2, y: -3, z: 0 },
                    caption: Some("Computer Museum")
                }
            ),
            code: "computer_museum_lobby",
            name: "Lobby",
            short: ansi!("<bgblack><white><lt>=<reset>"),
            description: ansi!("A large room, full of glass cases containing computer equipment from various eras, from ancient dusty looking machines, to miniturised modern equipment. Some of the computer equipment is even powered up, showing scrolling text and various demonstration images. A dusty staircase, above which is hung a faded sign saying <red>'Danger, robots in use, do not enter'<reset>, leads down"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 0, y: 0, z: 0 },
            exits: vec!(
                Exit {
                    direction: Direction::WEST,
                    target: ExitTarget::Custom("room/melbs_kingst_20"),
                    ..Default::default()
                },
                Exit {
                    direction: Direction::DOWN,
                    ..Default::default()
                },
            ),
            should_caption: true,
            ..Default::default()
        },
        Room {
            zone: "computer_museum",
            secondary_zones: vec![],
            code: "computer_museum_club_stairwell",
            name: "Stairwell",
            short: ansi!("<bgblack><yellow>>=<reset>"),
            description: ansi!("This appears to be the start of a long corridor. Floor, walls, and ceiling are all made of concrete. A plain concrete staircase leads up. Painted on the floor to the east is a red line adorned with the text <red>DANGER ROBOTS DO NOT CROSS<reset>. The corridor echoes with screams of torment and the sound of metal cutting into flesh. You can just make out a door at the east end of the corridor"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 0, y: 0, z: -1 },
            exits: vec!(
                Exit {
                    direction: Direction::UP,
                    ..Default::default()
                },
                Exit {
                    direction: Direction::EAST,
                    ..Default::default()
                },
            ),
            repel_npc: true,
            should_caption: true,
            ..Default::default()
        },
        Room {
            zone: "computer_museum",
            secondary_zones: vec![],
            code: "computer_museum_hw_1",
            name: "Corridor Segment 1",
            short: ansi!("<bgblack><yellow>==<reset>"),
            description: ansi!("This appears to be part of a long corridor. Floor, walls, and ceiling are all made of concrete. Painted on the ground to the west is the text <red>DANGER ROBOTS DO NOT CROSS<reset>. The corridor continues to the east. To the east, you see some kind of marking on the concrete wall. The corridor echoes with screams of torment and the sound of metal cutting into flesh. You can make out a door at the east end of the corridor, with some kind of electronic screen on it. A plaque on the wall tells you this is Corridor Segment 1"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 1, y: 0, z: -1 },
            exits: vec!(
                Exit {
                    direction: Direction::WEST,
                    ..Default::default()
                },
                Exit {
                    direction: Direction::EAST,
                    ..Default::default()
                },
            ),
            should_caption: false,
            ..Default::default()
        },
        Room {
            zone: "computer_museum",
            secondary_zones: vec![],
            code: "computer_museum_hw_2",
            name: "Corridor Segment 2",
            short: ansi!("<bgblack><yellow>==<reset>"),
            description: ansi!("This appears to be part of a long corridor. Floor, walls, and ceiling are all made of concrete. The corridor continues to the east and west. The corridor echoes with screams of torment and the sound of metal cutting into flesh. A stain, apparently done in blood, says in scrawled, panicked looking writing: <yellow><bgblack>Beware Robots! Discs to third tower<reset>. You can see a door at the east end of the corridor, with some kind of electronic screen on it, showing some kind of towers. A plaque on the wall tells you this is Corridor Segment 2"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 2, y: 0, z: -1 },
            exits: vec!(
                Exit {
                    direction: Direction::WEST,
                    ..Default::default()
                },
                Exit {
                    direction: Direction::EAST,
                    ..Default::default()
                },
            ),
            should_caption: false,
            ..Default::default()
        },
        Room {
            zone: "computer_museum",
            secondary_zones: vec![],
            code: "computer_museum_hw_3",
            name: "Corridor Segment 3",
            short: ansi!("<bgblack><yellow>==<reset>"),
            description: ansi!("This appears to be part of a long corridor. Floor, walls, and ceiling are all made of concrete. Painted on the ground to the west is the text <red>DANGER ROBOTS DO NOT CROSS<reset>. The corridor continues to the east and west. To the west, you see some kind of marking on the concrete wall. The corridor echoes with screams of torment and the sound of metal cutting into flesh. You can make out a door at the east end of the corridor, with some kind of electronic screen on it, showing some kind of towers. A plaque on the wall tells you this is Corridor Segment 3"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 3, y: 0, z: -1 },
            exits: vec!(
                Exit {
                    direction: Direction::WEST,
                    ..Default::default()
                },
                Exit {
                    direction: Direction::EAST,
                    ..Default::default()
                },
            ),
            should_caption: false,
            ..Default::default()
        },
        Room {
            zone: "computer_museum",
            secondary_zones: vec![],
            code: "computer_museum_club_door",
            name: "Doorwell",
            short: ansi!("<bgblack><yellow>/\\<reset>"),
            description: ansi!("This appears to be a security zone protecting access to a door to the north. A long corridor stretches to the west. The corridor echoes with screams of torment and the sound of metal cutting into flesh.\n\
                                Mounted on the door is a large screen, showing primative ASCII art of some towers, \
                                with with some kind of electronic screen on it, showing some kind of towers with \
                                coloured disks stacked on them.\n\
                                The disks are arranged as follows:\n\
                                Tower 1: A small <green>green disk<reset>, atop a medium sized <yellow>yellow disk<reset>, \
                                atop a large <bgblack><white>white disk<reset>, atop an extra large <red>red disk<reset>.\n\
                                Tower 2: Empty\n\
                                Tower 3: Empty"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 4, y: 0, z: -1 },
            exits: vec!(
                Exit {
                    direction: Direction::NORTH,
                    ..Default::default()
                },
                Exit {
                    direction: Direction::WEST,
                    ..Default::default()
                },
            ),
            should_caption: true,
            ..Default::default()
        },
        Room {
            zone: "computer_museum",
            secondary_zones: vec![],
            code: "computer_museum_hackers_club",
            name: "Hackers' Club",
            short: ansi!("<bgblack><green>HC<reset>"),
            description: ansi!("A room full of beeping and whirring equipment. One shiny stainless steel piece of equipment really catches your eye. It has a large plaque on it saying: Wristpad hacking unit - intelligence upgrade program"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 4, y: -1, z: -1 },
            exits: vec!(
                Exit {
                    direction: Direction::SOUTH,
                    ..Default::default()
                },
            ),
            should_caption: true,
            ..Default::default()
        },
    )
}
